@@ -38,6 +38,7 @@ extensions = [
     "m2r2",
     "nbsphinx",
     "nbsphinx_link",
+    "sphinxcontrib.autodoc_pydantic",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -61,6 +62,22 @@ napoleon_use_ivar = True
 # The suffix(es) of source filenames.
 source_suffix = [".rst", ".md"]
 
+# control pydantic model docs
+autodoc_pydantic_model_show_json = False
+autodoc_pydantic_model_show_field_summary = False
+autodoc_pydantic_model_show_config = False
+autodoc_pydantic_model_show_config_summary = False
+autodoc_pydantic_model_show_validator_members = False
+autodoc_pydantic_model_member_order = "bysource"
+autodoc_pydantic_settings_show_json = False
+autodoc_pydantic_settings_show_field_summary = False
+autodoc_pydantic_settings_show_config = False
+autodoc_pydantic_settings_show_config_summary = False
+autodoc_pydantic_settings_show_validator_members = False
+autodoc_pydantic_settings_member_order = "bysource"
+autodoc_pydantic_field_list_validators = False
+autodoc_pydantic_field_show_constraints = False
+
 # Config nbsphinx
 
 # Ensure env.metadata[env.docname]['nbsphinx-link-target'] points relative to repo root:
