@@ -1,9 +1,9 @@
-from pydantic import Field
+from pydantic import BaseModel, Field
 
-from jobflow import Schema, job
+from jobflow import job
 
 
-class ComputeSchema(Schema):
+class ComputeSchema(BaseModel):
     """Document defining job output schema."""
 
     total: float = Field(description="Sum of the inputs.")
@@ -17,7 +17,7 @@ def compute(a: float, b: float):
 
 compute_job = compute(1.1, 2.2)
 print(compute_job.output.total)
-# OutputReference(8ff2a94e-7633-42e9-8aa0-8479801347d5, 'total')
+# OutputReference(8ff2a94e-7633-42e9-8aa0-8479801347d5, .total)
 
 compute_job.output.not_in_schema
 # AttributeError: ComputeSchema does not have property 'not_in_schema'.
