@@ -439,12 +439,16 @@ class Job(MSONable):
 
         edges = []
         for uuid, refs in self.input_references_grouped.items():
-            properties = [
-                ".".join(map(str, ref.attributes_formatted))
+            properties: Union[List[str], str] = [
+                ref.attributes_formatted[-1]
+                .replace("[", "")
+                .replace("]", "")
+                .replace(".", "")
                 for ref in refs
                 if ref.attributes
             ]
-            properties = properties if len(properties) > 0 else ["output"]
+            properties = properties[0] if len(properties) == 1 else properties
+            properties = properties if len(properties) > 0 else "output"
             edges.append((uuid, self.uuid, {"properties": properties}))
 
         graph = DiGraph()
@@ -682,7 +686,7 @@ class Job(MSONable):
             subclasses.
         nested
             Whether to apply the updates to Maker objects that are themselves kwargs
-            of a Maker object. See examples for more details.
+            of Maker, job, or flow objects. See examples for more details.
         dict_mod
             Use the dict mod language to apply updates. See :obj:`.DictMods` for more
             details.
@@ -737,6 +741,8 @@ class Job(MSONable):
         ...     {"number": 10}, function_filter=AddMaker, nested=False
         ... )
         """
+        from jobflow import Maker
+
         if self.maker is not None:
             maker = self.maker.update_kwargs(
                 update,
@@ -746,14 +752,67 @@ class Job(MSONable):
                 dict_mod=dict_mod,
             )
             setattr(self, "function", getattr(maker, self.function.__name__))
+        elif nested:
+            # also look for makers in job args and kwargs
+            new_args = []
+            for arg in self.function_args:
+                if isinstance(arg, Maker):
+                    new_arg = arg.update_kwargs(
+                        update,
+                        name_filter=name_filter,
+                        class_filter=class_filter,
+                        nested=nested,
+                        dict_mod=dict_mod,
+                    )
+                    new_args.append(new_arg)
+                else:
+                    new_args.append(arg)
+            self.function_args = tuple(new_args)
+
+            for name, kwarg in self.function_kwargs.items():
+                if isinstance(kwarg, Maker):
+                    self.function_kwargs[name] = kwarg.update_kwargs(
+                        update,
+                        name_filter=name_filter,
+                        class_filter=class_filter,
+                        nested=nested,
+                        dict_mod=dict_mod,
+                    )
+
+    def append_name(self, append_str: str, prepend: bool = False):
+        """
+        Append a string to the name of the job.
+
+        Parameters
+        ----------
+        append_str
+            A string to append.
+        prepend
+            Prepend the name rather than appending it.
+        """
+        if prepend:
+            self.name = append_str + self.name
+        else:
+            self.name += append_str
 
     def as_dict(self) -> Dict:
         """Serialize the job as a dictionary."""
         d = super().as_dict()
 
-        # fireworks can't serialize functions, so explicitly serialize to avoid issues
-        d["function"] = jsanitize(d["function"])
-        return d
+        # fireworks can't serialize functions and classes, so explicitly serialize to
+        # the job recursively using monty to avoid issues
+        return jsanitize(d, strict=True, enum_values=True)
+
+    def __setattr__(self, key, value):
+        """Handle setting attributes. Implements a special case for job name."""
+        if key == "name" and value is not None and self.maker is not None:
+            # have to be careful and also update the name of the bound maker
+            # the ``value is not None`` in the if statement is needed otherwise the name
+            # of the maker will get set to None during class init
+            self.__dict__[key] = value
+            self.maker.name = value
+        else:
+            super().__setattr__(key, value)
 
 
 @dataclass
@@ -958,6 +1017,8 @@ def pass_manager_config(
         A job, flow, or list of jobs/flows.
     manager_config
         A manager config to pass on.
+    metadata
+        Metadata to pass on.
     """
     from copy import deepcopy
 
