@@ -20,6 +20,7 @@ def run_locally(
     log: bool = True,
     store: Optional[jobflow.JobStore] = None,
     create_folders: bool = False,
+    ensure_success: bool = False,
 ) -> Dict[str, Dict[int, jobflow.Response]]:
     """
     Run a :obj:`Job` or :obj:`Flow` locally.
@@ -31,10 +32,13 @@ def run_locally(
     log
         Whether to print log messages.
     store
-        A job store. If a job store is not specified then a maggma ``MemoryStore`` will
-        be used while the job is executed and deleted once the job is finished.
+        A job store. If a job store is not specified then
+        :obj:`JobflowSettings.JOB_STORE` will be used. By default this is a maggma
+        ``MemoryStore`` but can customised by setting the jobflow configuration file.
     create_folders
         Whether to run each job in a new folder.
+    ensure_success
+        Raise an error if the flow was not executed successfully.
 
     Returns
     -------
@@ -46,19 +50,16 @@ def run_locally(
     from pathlib import Path
     from random import randint
 
-    from maggma.stores import MemoryStore
     from monty.os import cd
 
-    from jobflow import Job, JobStore, initialize_logger
+    from jobflow import SETTINGS, Job, initialize_logger
     from jobflow.core.flow import get_flow
     from jobflow.core.reference import OnMissing
 
     if store is None:
-        jobstore = JobStore(MemoryStore())
-        jobstore.connect()
-    else:
-        jobstore = store
-        jobstore.connect()
+        store = SETTINGS.JOB_STORE
+
+    store.connect()
 
     if log:
         initialize_logger()
@@ -66,7 +67,7 @@ def run_locally(
     flow = get_flow(flow)
 
     stopped_parents: Set[str] = set()
-    fizzled: Set[str] = set()
+    errored: Set[str] = set()
     responses: Dict[str, Dict[int, jobflow.Response]] = defaultdict(dict)
     stop_jobflow = False
 
@@ -87,19 +88,19 @@ def run_locally(
             return
 
         if (
-            len(set(parents).intersection(fizzled)) > 0
+            len(set(parents).intersection(errored)) > 0
             and job.config.on_missing_references == OnMissing.ERROR
         ):
-            fizzled.add(job.uuid)
+            errored.add(job.uuid)
             return
 
         try:
-            response = job.run(store=jobstore)
+            response = job.run(store=store)
         except Exception:
             import traceback
 
             logger.info(f"{job.name} failed with exception:\n{traceback.format_exc()}")
-            fizzled.add(job.uuid)
+            errored.add(job.uuid)
             return
 
         responses[job.uuid][job.index] = response
@@ -155,7 +156,13 @@ def run_locally(
                 if response is False:
                     return False
 
+        return True if response is not None else False
+
     logger.info("Started executing jobs locally")
-    _run(flow)
+    finished_successfully = _run(flow)
     logger.info("Finished executing jobs locally")
+
+    if ensure_success and not finished_successfully:
+        raise RuntimeError("Flow did not finish running successfully")
+
     return dict(responses)
