@@ -62,6 +62,14 @@ def test_job_init():
     with pytest.raises(ValueError):
         Job(function=add, function_args=(1,), data=True, graphs=True)
 
+    # test changing job name (test needed due to setattr override
+    test_job = Job(function=add, function_args=("I am a job",))
+    test_job.name = "abc"
+    assert test_job.name == "abc"
+
+    test_job.name += "xyz"
+    assert test_job.name == "abcxyz"
+
 
 def test_job_run(capsys, memory_jobstore, memory_data_jobstore):
     from jobflow.core.job import Job, Response
@@ -590,6 +598,15 @@ def test_maker():
     test_job = maker.make(2)
     assert test_job.maker == maker
 
+    # test setting job name; should also update the maker name
+    test_job.name = "abc"
+    assert test_job.name == "abc"
+    assert test_job.maker.name == "abc"
+
+    test_job.name += "xyz"
+    assert test_job.name == "abcxyz"
+    assert test_job.maker.name == "abcxyz"
+
 
 def test_graph():
     from jobflow import Job
@@ -615,9 +632,7 @@ def test_graph():
     graph = test_job.graph
     assert len(graph.nodes) == 2
     assert len(graph.edges) == 1
-    assert graph.get_edge_data(test_job1.uuid, test_job.uuid)["properties"] == [
-        ".value"
-    ]
+    assert graph.get_edge_data(test_job1.uuid, test_job.uuid)["properties"] == "value"
 
     # test arg and kwargs inputs
     test_job1 = Job(add, function_args=(1,), function_kwargs={"b": 2})
@@ -640,8 +655,8 @@ def test_graph():
     assert len(graph.nodes) == 2
     assert len(graph.edges) == 1
     assert set(graph.get_edge_data(test_job1.uuid, test_job.uuid)["properties"]) == {
-        ".value",
-        ".name",
+        "value",
+        "name",
     }
 
 
@@ -700,6 +715,10 @@ def test_update_maker_kwargs():
         def make(self, a):
             return a + self.b
 
+    @job
+    def outer_job(maker1, maker2=None):
+        pass
+
     # test no maker
     test_job = Job(add, function_args=(1,), function_kwargs={"b": 2})
     test_job.update_maker_kwargs({"b": 5})
@@ -745,6 +764,33 @@ def test_update_maker_kwargs():
     test_job.update_maker_kwargs({"_inc": {"b": 10}}, dict_mod=True)
     assert test_job.maker.b == 13
 
+    # test makers in job args and kwargs
+    maker1 = AddMaker(b=1)
+    maker2 = AddMaker(b=2)
+    test_job = outer_job(maker1, maker2=maker2)
+    test_job.update_maker_kwargs({"_inc": {"b": 10}}, dict_mod=True)
+    assert test_job.function_args[0].b == 11
+    assert test_job.function_kwargs["maker2"].b == 12
+
+    # test nested=False does not impact the jobs
+    test_job.update_maker_kwargs({"_inc": {"b": 20}}, dict_mod=True, nested=False)
+    assert test_job.function_args[0].b == 11
+    assert test_job.function_kwargs["maker2"].b == 12
+
+
+def test_append_name():
+    from jobflow import Job
+
+    # test append
+    test_job = Job(function=add)
+    test_job.append_name(" test")
+    assert test_job.name == "add test"
+
+    # test prepend
+    test_job = Job(function=add)
+    test_job.append_name("test ", prepend=True)
+    assert test_job.name == "test add"
+
 
 def test_output_schema(memory_jobstore):
     from pydantic import BaseModel
